Import-Module DataONTAP -ErrorAction SilentlyContinue

# I was experimenting with requiring credentials (below) originally, but
# I can successfully run this script against a 7.3.6P1 filer
# without requiring them.
#
# set the credential information
#$ControllerPassword = ConvertTo-SecureString -String "INPUT_FILER_PASSWORD_HERE" #-AsPlainText -force
#$ControllerCredential = New-Object #System.Management.Automation.PsCredential("INPUT_USER_ID_HERE",$ControllerPassword)
 
# Enter The Controller Names separated by Comma
$controller = @('INPUT_FILER_NAME(S)_HERE')

# location to be saved
$reportLocation = "INPUT_LOCATION_FOR_EXCEL_REPORT_HERE"

# get the date
$date = Get-Date -Format MM/dd/yy 

# create an Excel object
$Excel = new-Object -comobject Excel.Application  
$Excel.visible = $True
$lastRow = 2

# check if there is a report that already exists 
if (Test-Path $reportLocation)  
{  
# Open the document and check the last row 
$TempExcel = $Excel.WorkBooks.Open($reportLocation)  
$worksheet = $TempExcel.Worksheets.Item(1) 
$worksheet.activate()
$lastRow = $worksheet.UsedRange.rows.count + 1
} else {  
# Create a new document  
$TempExcel = $Excel.Workbooks.Add()  
$worksheet = $TempExcel.Worksheets.Item(1)  

# set the headers
$workSheet.cells.Item(1,1) = "Date" 
$workSheet.cells.Item(1,2) = "Filer"
$workSheet.cells.Item(1,3) = "Aggregate" 
$workSheet.cells.Item(1,4) = "Total(GB)"
$workSheet.cells.Item(1,5) = "Available(GB)"
$workSheet.cells.Item(1,6) = "used(GB)"

# set the column widths
$workSheet.Columns.Item(1).columnWidth = 12
$workSheet.Columns.Item(2).columnWidth = 9
$workSheet.Columns.Item(3).columnWidth = 9
$workSheet.Columns.Item(4).columnWidth = 9
$workSheet.Columns.Item(5).columnWidth = 15
$workSheet.Columns.Item(6).columnWidth = 9

# align cells
$workSheet.Columns.Item(1).HorizontalAlignment = -4131

} 

# loop through each filer 
Foreach ($filer in $controller)
{
	# connect to the filer
	Connect-NaController -Name $filer 
	#-Credential $ControllerCredential
	
	# get the filer name
	$filerName = Get-NaSystemInfo | Select -ExpandProperty "SystemName"
	
	# get the aggregate info
	foreach ($aggr in Get-NaAggr)
	{
		$aggrName = Get-NaAggr | Select -ExpandProperty "Name"
		
		$aggrTotalT = Get-NaAggr | Select -ExpandProperty "SizeTotal"
		$aggrTotal = [math]::Round($aggrTotalT / 1GB, 2)

		$aggrAvailT = Get-NaAggr | Select -ExpandProperty "SizeAvailable"
		$aggrAvail = [math]::Round($aggrAvailT / 1GB, 2)

		$aggrUsedT = Get-NaAggr | Select -ExpandProperty "SizeUsed"
		$aggrUsed = [math]::Round($aggrUsedT / 1GB, 2)
		
		# enter info into the spreadsheet
		$workSheet.cells.Item($lastRow,1) = $date
		$workSheet.cells.Item($lastRow,2) = $filerName
		$workSheet.cells.Item($lastRow,3) = $aggrName
		$workSheet.cells.Item($lastRow,4) = $aggrTotal
		$workSheet.cells.Item($lastRow,5) = $aggrAvail
		$workSheet.cells.Item($lastRow,6) = $aggrUsed
		
		# keep track on the rows
		$lastRow++;
		
	}
	
}	

# save the file 
if (Test-Path $reportLocation) {  
$Excel.ActiveWorkBook.Save()  
} else {  
$Excel.activeworkbook.saveas($reportLocation)  
}

# garbage collection  
$worksheet = $null  
$d = $null  
$TempExcel.Close()  
$TempExcel = $null  
$Excel.Quit()  
$Excel = $null  
[GC]::Collect() 

Write-Verbose "Completed Collecting Aggregate Information for $filer" -Verbose

 
